@@ -5,4 +5,5 @@ from .imputers import PerColumnImputer, SimpleImputer, Imputer
 from .scalers import StandardScaler
 from .column_selectors import DropColumns, SelectColumns
 from .dimensionality_reduction import LinearDiscriminantAnalysis, PCA
-from .preprocessing import DateTimeFeaturizer, DropNullColumns, LSA, TextFeaturizer, DelayedFeatureTransformer, DFSTransformer, PolynomialDetrender, PreprocessTransformer
+from .preprocessing import DateTimeFeaturizer, DropNullColumns, LSA, TextFeaturizer, DelayedFeatureTransformer, DFSTransformer, PolynomialDetrender
+from .preprocessing import PreprocessTransformer
