@@ -10,6 +10,8 @@ from collections import OrderedDict
 import numpy as np
 import cloudpickle
 import pandas as pd
+from dask_ml.wrappers import ParallelPostFit
+from .dask_wrapper import AVMWrapper
 
 from bciavm.utils.bci_utils import preprocess_data
 from .components import (
@@ -470,6 +472,30 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         self.input_target_name = y.name
         self._component_graph.fit(X, y)
         self.input_feature_names = self._component_graph.input_feature_names
+        self._parallel_post_fit(self._component_graph, X, y)
+
+    def _parallel_post_fit(self, estimator, X, y=None):
+        """Meta-estimator for parallel predict and transform.
+
+        Warning
+        This class is not appropriate for parallel or distributed training on large datasets.
+        For that, see Incremental, which provides distributed (but sequential) training.
+        If you’re doing distributed hyperparameter optimization on larger-than-memory datasets,
+        see dask_ml.model_selection.IncrementalSearch.
+
+        Arguments:
+            estimator : Estimator
+            X (ww.DataTable, pd.DataFrame or np.ndarray): The input training data of shape [n_samples, n_features]
+            y (ww.DataColumn, pd.Series, np.ndarray): The target training data of length [n_samples]
+
+        Returns:
+            Estimator wrapped in Dask ParallelPostFit
+        """
+        wrapped_model = AVMWrapper(estimator)
+        wmodel = ParallelPostFit(wrapped_model)
+        wmodel.fit(X, y)
+        self._dask_component_graph = wmodel
+        return self
 
     @abstractmethod
     def fit(self, X, y):
@@ -500,6 +526,26 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         predictions.name = self.input_target_name
         return infer_feature_types(predictions)
 
+    def parallel_predict(self, X, scheduler='distributed', n_jobs=None, columns=['unit_index', 'avm', 'avm_lower', 'avm_upper', 'conf', 'ts',
+                                                 'latest_production_version', 'latest_staging_version']):
+        """Make predictions using selected features.
+
+        Arguments:
+            X (dd.DataFrame, pd.DataFrame, or np.ndarray): Data of shape [n_samples, n_features]
+            columns (list): The list of columns to use when returning predictions
+            scheduler: The dask scheduler type.
+            n_jobs: The number of parallel jobs - should equal npartitions in the dask dataframe
+
+        Returns:
+            pd.DataFrame: Predicted values.
+        """
+        if n_jobs is not None:
+            predictions = self._dask_component_graph.predict(X).compute(scheduler=scheduler, n_jobs=n_jobs)
+        else:
+            predictions = self._dask_component_graph.predict(X).compute(scheduler=scheduler)
+
+        return pd.DataFrame(predictions, columns=columns)
+
     @abstractmethod
     def score(self, X, y, objectives):
         """Evaluate model performance on current and additional objectives
